@@ -11,11 +11,11 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: countries.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
+    $FileInfo: countries.py - Last Update: 3/27/2023 Ver. 2.8.13 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
-import sys, re, upcean.validate;
+import re, upcean.validate;
 
 '''
 // Get GS1 Prefix for EAN-13 EAN-9 barcodes
@@ -401,7 +401,7 @@ def get_isbn_identifier(upc):
  upc = upc.replace("-", "");
  upc = upc.replace(" ", "");
  if(len(upc)>10):
-  fix_matches = re.findall("^(\d{9})(\d{1}|X{1})", upc); 
+  fix_matches = re.findall("^(\d{9})(\d{1}|X{1})", upc);
   fix_matches = fix_matches[0]
   upc = fix_matches[0]+fix_matches[1];
  if(len(upc)>10 or len(upc)<10):
