@@ -11,20 +11,20 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: oopfuncs.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
+    $FileInfo: oopfuncs.py - Last Update: 3/27/2023 Ver. 2.8.13 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
-import upcean.validate, upcean.convert, upcean.getprefix, upcean.barcodes.getsfname, upcean.support;
+import upcean.validate, upcean.convert, upcean.getprefix, upcean.encode.getsfname, upcean.support;
 pilsupport = upcean.support.check_for_pil();
 cairosupport = upcean.support.check_for_cairo();
 if(pilsupport or cairosupport):
- import upcean.fonts, upcean.xml, upcean.barcodes;
+ import upcean.fonts, upcean.xml, upcean.encode;
 if(pilsupport):
  import upcean.decode;
 
 ''' // Object-oriented classes and functions by Kazuki Przyborowski '''
-class barcode:
+class encode:
  ''' // Barcode Types '''
  EAN2="ean2";
  UPCS2="ean2";
@@ -104,31 +104,43 @@ class barcode:
     filename = self.filename;
    if(size is None):
     size = self.size;
-   return upcean.barcodes.create_barcode(self.type, self.code, filename, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return upcean.encode.create_barcode(self.type, self.code, filename, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
   def validate_create_barcode(self, filename=None, size=None):
    if(filename is None):
     filename = self.filename;
    if(size is None):
     size = self.size;
-   return upcean.barcodes.validate_create_barcode(self.type, self.code, filename, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return upcean.encode.validate_create_barcode(self.type, self.code, filename, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
   def fix_create_barcode(self, filename=None, size=None):
    if(filename is None):
     filename = self.filename;
    if(size is None):
     size = self.size;
-   return upcean.barcodes.fix_create_barcode(self.type, self.code, filename, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return upcean.encode.fix_create_barcode(self.type, self.code, filename, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
   def draw_barcode(self, size=None):
    if(size is None):
     size = self.size;
-   return upcean.barcodes.draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return upcean.encode.draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+  def encode_barcode(self, size=None):
+   if(size is None):
+    size = self.size;
+   return upcean.encode.draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
   def validate_draw_barcode(self, size=None):
    if(size is None):
     size = self.size;
-   return upcean.barcodes.validate_draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return upcean.encode.validate_draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+  def validate_encode_barcode(self, size=None):
+   if(size is None):
+    size = self.size;
+   return upcean.encode.validate_draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
   def fix_draw_barcode(self, size=None):
    if(size is None):
     size = self.size;
-   return upcean.barcodes.fix_draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return upcean.encode.fix_draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+  def fix_encode_barcode(self, size=None):
+   if(size is None):
+    size = self.size;
+   return upcean.encode.fix_draw_barcode(self.type, self.code, size, (self.hidesn, self.hidecd, self.hidetext), self.barheight, self.barwidth, self.textxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
  ''' // validate/__init__.py funtions '''
  def validate_checksum(self):
   return upcean.validate.validate_checksum(self.type, self.code, self.return_check);
@@ -202,11 +214,13 @@ class barcode:
   def get_save_filename(self, filename=None):
    if(filename is None):
     filename = self.filename;
-   return upcean.barcodes.getsfname.get_save_filename(self.filename);
+   return upcean.encode.getsfname.get_save_filename(self.filename);
  ''' // getprefix/__init__.py funtions '''
  def get_barcode_info(self):
   return upcean.getprefix.get_barcode_info(self.type, self.code);
 
+barcode = encode;
+
 ''' // Object-oriented classes and functions by Kazuki Przyborowski '''
 class decode:
  ''' // Barcode Types '''
@@ -240,9 +254,10 @@ class decode:
   if(filename is not None):
    self.filename = filename;
   self.code = None;
+  self.info = None;
   self.size = 1;
   self.barheight = (48, 54);
-  self.barwidth = 1;
+  self.barwidth = (1, 1);
   self.shiftxy = (0, 0);
   self.barcolor = (0, 0, 0);
   self.textcolor = (0, 0, 0);
@@ -250,25 +265,41 @@ class decode:
   self.imageoutlib = "pillow";
   self.return_check = False;
   self.return_type = "dict";
+  self.locatebarcode = False;
+  self.shiftcheck = False;
  if(pilsupport):
   def decode_barcode(self, filename=None, size=None):
    if(filename is None):
     filename = self.filename;
    if(size is None):
     size = self.size;
-   self.code = upcean.decode.decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   self.code = upcean.decode.decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftcheck, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.locatebarcode, self.imageoutlib);
    return self.code;
+  def get_barcode_info(self, filename=None, size=None):
+   if(filename is None):
+    filename = self.filename;
+   if(size is None):
+    size = self.size;
+   self.info = upcean.decode.get_barcode_location(self.type, filename, size, self.barheight, self.barwidth, self.shiftcheck, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return self.info;
+  def get_barcode_location(self, filename=None, size=None):
+   if(filename is None):
+    filename = self.filename;
+   if(size is None):
+    size = self.size;
+   self.info = upcean.decode.get_barcode_location(self.type, filename, size, self.barheight, self.barwidth, self.shiftcheck, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   return self.info;
   def validate_decode_barcode(self, filename=None, size=None):
    if(filename is None):
     filename = self.filename;
    if(size is None):
     size = self.size;
-   self.code = upcean.decode.decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   self.code = upcean.decode.decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftcheck, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.locatebarcode, self.imageoutlib);
    return self.code;
   def fix_decode_barcode(self, filename=None, size=None):
    if(filename is None):
     filename = self.filename;
    if(size is None):
     size = self.size;
-   self.code = upcean.decode.fix_decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.imageoutlib);
+   self.code = upcean.decode.fix_decode_barcode(self.type, filename, size, self.barheight, self.barwidth, self.shiftcheck, self.shiftxy, (self.barcolor, self.textcolor, self.bgcolor), self.locatebarcode, self.imageoutlib);
    return self.code;
