@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: shortcuts.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
+    $FileInfo: shortcuts.py - Last Update: 3/27/2023 Ver. 2.8.13 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -22,6 +22,16 @@ import upcean.oopfuncs.oopfuncs, upcean.support;
 // oopfuncs
 '''
 
+def barcode_encode(type=None, code=None):
+ if(type not in upcean.support.supported_barcodes("tuple")):
+  return False;
+ return upcean.oopfuncs.oopfuncs.encode(type, code);
+
+def encode_barcode(type=None, code=None):
+ if(type not in upcean.support.supported_barcodes("tuple")):
+  return False;
+ return upcean.oopfuncs.oopfuncs.encode(type, code);
+
 def barcode_class(type=None, code=None):
  if(type not in upcean.support.supported_barcodes("tuple")):
   return False;
