@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: files.py - Last Update: 3/25/2023 Ver. 2.8.8 RC 1 - Author: cooldude2k $
+    $FileInfo: files.py - Last Update: 3/27/2023 Ver. 2.8.13 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -40,7 +40,7 @@ if(sys.version[0]>="3"):
  import urllib.parse as urlparse;
 from xml.sax.saxutils import XMLGenerator;
 from upcean.versioninfo import __author__, __copyright__, __credits__, __email__, __license__, __maintainer__, __project__, __project_url__, __revision__, __status__, __version__, __version_alt__, __version_date__, __version_date_alt__, __version_date_info__, __version_info__, version_date, version_info;
-import upcean.barcodes.barcode, upcean.barcodes.shortcuts;
+import upcean.encode.barcode, upcean.encode.shortcuts;
 
 ''' // User-Agent string for http/https requests '''
 useragent_string = "Mozilla/5.0 (compatible; {proname}/{prover}; +{prourl})".format(proname=__project__, prover=__version_alt__, prourl=__project_url__);
@@ -64,12 +64,12 @@ def create_barcode_from_xml_file(xmlfile, draw=False):
   xmlheaders = {'User-Agent': useragent_string};
   try:
    tree = cElementTree.ElementTree(file=urllib2.urlopen(urllib2.Request(xmlfile, None, xmlheaders)));
-  except cElementTree.ParseError: 
+  except cElementTree.ParseError:
    return False;
  else:
   try:
    tree = cElementTree.ElementTree(file=xmlfile);
-  except cElementTree.ParseError: 
+  except cElementTree.ParseError:
    return False;
  root = tree.getroot();
  bcdrawlist = [];
@@ -135,7 +135,7 @@ def create_barcode_from_xml_file(xmlfile, draw=False):
     xmlbarcode.update({"barcolor": colorlist});
    if('imageoutlib' in child.attrib):
     xmlbarcode.update({"imageoutlib": tuple(map(int, child.attrib['imgoutlib'].split()))});
-   bcstatinfo = upcean.barcodes.shortcuts.validate_create_barcode(**xmlbarcode);
+   bcstatinfo = upcean.encode.shortcuts.validate_create_barcode(**xmlbarcode);
    if(draw or 'file' not in child.attrib):
     bcdrawlist.append(bcstatinfo);
    if(not bcstatinfo):
@@ -156,12 +156,12 @@ def convert_from_xml_to_json_file(xmlfile, jsonfile=None):
   xmlheaders = {'User-Agent': useragent_string};
   try:
    tree = cElementTree.ElementTree(file=urllib2.urlopen(urllib2.Request(xmlfile, None, xmlheaders)));
-  except cElementTree.ParseError: 
+  except cElementTree.ParseError:
    return False;
  else:
   try:
    tree = cElementTree.ElementTree(file=xmlfile);
-  except cElementTree.ParseError: 
+  except cElementTree.ParseError:
    return False;
  bctree = tree.getroot();
  bctreeln = len(bctree);
@@ -212,7 +212,7 @@ def create_barcode_from_json_file(jsonfile, draw=False):
   jsonfile.close();
  try:
   bctree = tree['barcodes']['barcode'];
- except: 
+ except:
   return False;
  bctreeln = len(bctree);
  bctreect = 0;
@@ -276,7 +276,7 @@ def create_barcode_from_json_file(jsonfile, draw=False):
    jsonbarcode.update({"barcolor": colorlist});
   if('imageoutlib' in bctree[bctreect]):
    jsonbarcode.update({"imageoutlib": tuple(map(int, bctree[bctreect]['imgoutlib'].split()))});
-  bcstatinfo = upcean.barcodes.shortcuts.validate_create_barcode(**jsonbarcode);
+  bcstatinfo = upcean.encode.shortcuts.validate_create_barcode(**jsonbarcode);
   if(draw or 'file' not in bctree[bctreect]):
    bcdrawlist.append(bcstatinfo);
   if(not bcstatinfo):
@@ -304,7 +304,7 @@ def convert_from_json_to_xml_file(jsonfile, xmlfile=None):
   jsonfile.close();
  try:
   bctree = tree['barcodes']['barcode'];
- except: 
+ except:
   return False;
  bctreeln = len(bctree);
  bctreect = 0;
@@ -445,7 +445,7 @@ def create_barcode_from_qs_file(qsfile, draw=False):
    pass;
   except IndexError:
    pass;
-  bcstatinfo = upcean.barcodes.shortcuts.validate_create_barcode(**qsbarcode);
+  bcstatinfo = upcean.encode.shortcuts.validate_create_barcode(**qsbarcode);
   if(draw or nofilesave ):
    bcdrawlist.append(bcstatinfo);
   if(not bcstatinfo):
